@@ -13,8 +13,7 @@ class MyPillow(Script):
     def run(self, page) -> pomace.Page:
         person = pomace.fake.person
 
-        log.info("Clearing cookies")
-        pomace.shared.browser.cookies.delete()
+        pomace.shared.client.clear_cookies()
         page = pomace.visit(self.URL)
 
         log.debug("Waiting for modal...")
@@ -26,21 +25,28 @@ class MyPillow(Script):
         else:
             log.warn("No modal found")
 
+        log.info(f"Submitting email address: {person.email_address}")
+        page.fill_email_address(person.email_address)
+        page = page.click_activate_offer(wait=1)
         log.info(f"Submitting phone number: {person.phone}")
         page.fill_phone(person.phone)
-        return page.click_submit()
+        return page.click_get_mobile_alerts(wait=1)
 
     def check(self, page) -> bool:
-        return "Thank you!" in page
+        success = "Thanks!" in page
+        if success:
+            page.click_continue_shopping(wait=0)
+        return success
 
 
 class FrankSpeech(Script):
 
     URL = "https://frankspeech.com/"
+    SKIP = True
 
     def run(self, page) -> pomace.Page:
         log.info("Clearing cookies")
-        pomace.shared.browser.cookies.delete()
+        pomace.shared.client.clear_cookies()
         page = pomace.visit(self.URL)
 
         page.fill_phone_number(pomace.fake.phone_number.replace("-", ""))
