@@ -54,39 +54,19 @@ class TommyBryant(Script):
         return "submission has been received" in page
 
 
-class HelmsOptical(Script):
+class JamesCraig(Script):
 
-    URL = "https://helmsoptical.com"
+    URL = "https://chiefjamescraig.com"
 
     def run(self, page) -> pomace.Page:
-        page.click_contact_us()
-
         person = pomace.fake.person
-        page.fill_name(person.name)
+
+        pomace.log.info(f"Beginning iteration as {person}")
+        page.fill_first_name(person.first_name)
         page.fill_email(person.email)
-        page.fill_message(
-            random.choice(
-                [
-                    "Barbara said Ivermectin cure my blindness, true?",
-                    "Does COVID make my vision better? Dr. Helms said it would.",
-                    "Should I get COVID to improve my vision like Helms said?",
-                    "Do I still need glasses if I had COVID? Dr. Helms wasn't clear.",
-                    "Barbara wasn't wearing a mask. Should I stop wearing glasses with masks?",
-                    "Dr. Helms refused to wear a mask.",
-                    "Dr. Helms had COVID and didn't wear a mask.",
-                    "Dr. Helms is unvaccinated and put me at risk.",
-                    "Barbara told me she's not going to get vaccinated.",
-                    "Do I need glasses if I've taken Ivermectin?",
-                    "Does Ivermectin improve my vision?",
-                    "Do I still need glasses if I've taken Ivermectin?"
-                    "Does Ivermectin cure my poor vision?",
-                    "Barbara took Ivermectin, should I?",
-                    "No one in the office was wearing a mask!",
-                    "I felt unsafe because the doctor was not wearing a mask.",
-                ]
-            )
-        )
-        return page.click_send(wait=1)
+        page.fill_phone(person.phone)
+        page.click_optional(wait=0)
+        return page.click_submit()
 
     def check(self, page) -> bool:
-        return "Thank you" in page or "Contact Us" in page
+        return "winred" in page.url
